function c = cortex (sfile, secondarg, eye_on_off, conversion)

% @cortex\cortex.m
% The constructor for the @cortex class;
% creates a @cortex object from a disk file.
%
% Syntax: COBJ = CORTEX (FILENAME, CLUSTERS, EYEONOFF, DVA_CONV);
%
% FILENAME: path/name of the CORTEX data file;
% CLUSTERS: set of event codes that should be interpreted as
%           spikes whenever they appear in the CORTEX data file;
% EYEONOFF: a 2-element array containing the EYE_ON and EYE_OFF
%           event codes; EYE_OFF is optional and is only used
%           to provides a data integrity check;
% DVA_CONV: EyePos-to-dva conversion factor;
%
% Depending on the number of arguments you pass, cortex.m will
% do the following:
%
% 0: creates an empty @cortex object;
%
% 1: if the filename extension is '.nex' then the object is
%    created from a nex file, otherwise the object is created
%    from a @cortex-optimized "dump" file
%
% 2: the object is created from a standard @cortex data file;
%    any existing EyePos data are ignored
%
% 4: the object is created from a standard @cortex data file;
%    EyePos data are included in the object
%
% 3: same as above, but the number 204.8 is used as default
%    dva conversion factor (corresponding to a value range 
%    of -2048 to 2048 spanning a 20-by-20 dva fixation window;
%    check your cortex.cfg)
%
% Last modified: 5 Feb 04

% 21 apr 99: changemode field added
% 11 jun 99: version #, rel_trial added
% 26 Aug 99: avoid warning for 0-event trials
% 21 May 00: help text and comments
%            EyePos stuff integrated into object!
%            Ver.2
% 24 May 00: help text revised
%  1 Aug 02: this function only parses arguments; specific
%            functions in 'private' called from here
% 10 Oct 02: end of @newcortex testing phase
% 30 Nov 02: help bits
%  5 Feb 04: fixed bug found by Bjoerg
%            (secondarg missing in case 3 and 4)

fun = 'loadraw';
try
   if strcmp (sfile (end-3:end), '.nex')
      fun = 'loadnex';
   end
end
   
switch nargin
case 0
   c = emptycobject;
case 1
   if strcmp (fun, 'loadnex')
      c = loadnex (sfile);
   else
      c = loadump (sfile);
   end
case 2
   c = feval (fun, sfile, secondarg);
case 3
   c = feval (fun, sfile, secondarg, eye_on_off, 204.8);
case 4
   c = feval (fun, sfile, secondarg, eye_on_off, conversion);
otherwise
   error ('wrong number of arguments');
end
c=class(c, 'cortex');