function [frates, instances] = meanfiringrate (c, cluster, binsize, k, group)

%@CORTEX/MEANFIRINGRATE  Average firing rates from a @cortex object.
%
%   [FRATE,INSTANCES] = MEANFIRINGRATE(COBJ,CLUSTER,KEY) returns the mean
%       firing activity (FRATE) of the neuron specified by CLUSTER, within
%       the COBJ @cortex object, for the experimental condition(s) and
%       epoch specified by KEY, a single key from a @key object. INSTANCES
%       is the number of trial epochs included in the analysis.
%
%   [FRATES,INSTANCES] = MEANFIRINGRATE(COBJ,CLUSTER,BINSIZE,KEY) divides
%       the analysis epoch specified by KEY in bins of BINSIZE width (in
%       ms), and computes average firing rates (FRATES) separately for each
%       bin. If the analysis epoch is not a multiple of BINSIZE, all
%       trailing milliseconds are ignored.
%
% Last modified: 19 Sep 03

% 29 mar 00: added single argument call (spm)
% 14 Jul 00: help text fixes
%  9 Nov 02: this function is now overloaded
% 16 Apr 03: help text
% 17 Apr 03: call to truncspm
% 22 Apr 03: sum(spmat, 1) bugfix
% 19 Sep 03: help text revised

switch nargin
   case 5
      % this in case the caller is using the now obsolete rules and groups)
      spmat = spikematrix (c, cluster, k, group);
   case 4
      spmat = spikematrix (c, cluster, k);
   case 3
      spmat = spikematrix (c, cluster, binsize);
      binsize = size (spmat, 2);
   otherwise
      error ('wrong number of arguments');
end

if prod (size(binsize))>1
   error ('binsize should be a scalar');
end
% make sure that the length of the array is a multiple of binsize
[spmat, instances, winsize, numofbins] = truncspm (spmat, binsize);

% compute the firing rates
spmat = reshape(sum(spmat, 1), binsize, numofbins);
spptr = double(sum(spmat, 1))/instances;
frates  = spptr / binsize * 1000;