
function c = loadump (source_filename)

% Last modified: 11 Dec 02

%========================================
%  1 May 02: last unnoted changes
% 11 Dec 02: temporarily revert to ver.2

f = openfile (source_filename, 'r');
temp = fread (f, 1, 'int16');
if temp==26
   erm = sprintf (...
      ['%s appears to be a raw cortex data file;\n'...
      'use cortex(filename,clusters) syntax!'],...
      source_filename);
   error (erm);
end
frewind (f);
% from ver. 1 on, version number is written at the beginning
% of the dump file, following the '@@@' identifying string
temp = char (fread (f, 3, 'char'))';
if strcmp (temp, '@@@')
   c.version = fread (f,  1, 'uint16');
   tn = char (fread (f, 30, 'char'))';
   c.name    = deblank (tn);
else
   % older dump files do not have the version number
   c.version = 0;
   tn = char (fread (f, 27, 'char'))';
   c.name    = [temp deblank(tn)];
end

t                   = fread (f, 1,     'uint16');
c.trials            = t;
c.cond_no           = fread (f, t,     'uint16');
c.repeat_no         = fread (f, t,     'uint16');
c.block_no          = fread (f, t,     'uint16');
c.eog_rate          = fread (f, t,     'uint8' );
c.KHz_resolution    = fread (f, t,     'uint8' );
c.trial_type        = fread (f, t,      'int16');
c.exp_response      = fread (f, t,      'int16');
c.response          = fread (f, t,     'uint16');
m                   = fread (f, 1,     'uint16');
c.times             = fread (f, [t,m], 'uint32');
c.codes             = fread (f, [t,m],  'int16');
u                   = fread (f, 1,     'uint16'); % the number of different clusters in this file
c.cluster_bank      = fread (f, u,     'uint16'); % the list of cluster codes
c.spike_start       = fread (f, [t,u], 'uint32' );
c.spike_end         = fread (f, [t,u], 'uint32' );
last_spike  = max (max (c.spike_end));

% this is necessary in case the file contains no spikes
if isempty (last_spike), last_spike = 0; end

% all the time stamps for all the clusters
c.spikes = uint32 (fread (f, last_spike, 'uint32' ));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% from here on, version-dependent stuff
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%
% version 1 and up
if c.version > 0
   c.changemode = fread (f, 1, 'uint8' );
   c.rel_trial  = fread (f, t, 'uint16');
else
   c.changemode = 0;
   c.rel_trial  = 1:c.trials;
end

%%%%%%%%%%%%%%%%%%
% version 2 and up
if c.version > 1
   c.eog2dva = fread (f, 1, 'float32');
else
   c.eog2dva = 0;
end

% if eog2dva ~= 0 then read in EyePos data
if c.eog2dva
   c.eog_start      = fread (f, t, 'uint32');
   c.eog_ptr_start  = fread (f, t, 'uint32');
   c.eog_ptr_end    = fread (f, t, 'uint32');
   le = max (c.eog_ptr_end);
   c.eog_X    = int16(fread (f, le, 'int16'));
   c.eog_Y    = int16(fread (f, le, 'int16'));
else
   c.eog_start      = [];
   c.eog_ptr_start  = [];
   c.eog_ptr_end    = [];
   c.eog_X    = int16([]);
   c.eog_Y    = int16([]);
end

%%%%%%%%%%%%%%%%%%
% version 3 and up

% if c.version > 2
%     c.spike_channel = fread (f, u, 'uint16');
%     
%     
%     c.spike_channel     = [];
%     c.vretrace          = [];
%     c.lfp_start         = [];
%     c.lfp_ptr_start     = [];
%     c.lfp_ptr_end       = [];
%     c.lfp_channel       = [];
%     c.lfps        = int16([]);
%     
% end

fclose (f);
disp (['File ''', source_filename, ''', preprocessed from ''', c.name, ''', loaded and ready.']);
return % to main
