function save (c, name)

% @cortex/save.m
% Dumps to disk the entire content of a @cortex object.
% Loading such preprocessed file back to memory is very fast
%
% Syntax 1: SAVE (COBJ, FILENAME);
% Syntax 2: COBJ.SAVE (FILENAME);
%
% Last modified: 11 Dec 02

% 21 apr 99: field changemode added, same name check
% 12 jun 99: version #, rel_trial added
% 10 dec 99: small change in screen output
% 21 may 00: ver.2: eog support + bug fixes
%  1 may 02: ver.3: nex support
% 11 dec 02: revert to ver.2 until plexon stuff is actually done

VERS = 2;
if strcmp (name, c.name)
   error ('use a different file name than the original');
end

f = openfile (name, 'w');

cm = c.changemode;
if cm>1
   cm = cm - 2;
end

% version 0
fwrite (f, '@@@');
fwrite (f, VERS,                'uint16'); % version number
fwrite (f, c.name                       );
fwrite (f, blanks (30-length(c.name))   );
fwrite (f, c.trials,            'uint16');
fwrite (f, c.cond_no,           'uint16');
fwrite (f, c.repeat_no,         'uint16');
fwrite (f, c.block_no,          'uint16');
fwrite (f, c.eog_rate,          'uchar' );
fwrite (f, c.KHz_resolution,    'uchar' );
fwrite (f, c.trial_type,         'int16');
fwrite (f, c.exp_response,       'int16');
fwrite (f, c.response,          'uint16');
[trials maxevents] = size (c.times);
fwrite (f, maxevents,           'uint16');
fwrite (f, c.times,             'uint32' );
fwrite (f, c.codes,             'uint16');
fwrite (f, length (c.cluster_bank), 'uint16');
fwrite (f, c.cluster_bank,      'uint16');
fwrite (f, c.spike_start,       'uint32');
fwrite (f, c.spike_end,         'uint32');
fwrite (f, double (c.spikes),   'uint32');

% version 1
fwrite (f, cm,                  'uint8' );
fwrite (f, c.rel_trial,         'uint16');

% version 2
fwrite (f, c.eog2dva,          'float32');
if c.eog2dva
   fwrite (f, c.eog_start,      'uint32');
   fwrite (f, c.eog_ptr_start,  'uint32');
   fwrite (f, c.eog_ptr_end,    'uint32');
   fwrite (f, c.eog_X,           'int16');
   fwrite (f, c.eog_Y,           'int16');
end

% version 3

% fwrite (f, c.spike_channel,     'uint16');
% fwrite (f, c.vretrace          = [];
% c.lfp_start         = [];
% c.lfp_ptr_start     = [];
% c.lfp_ptr_end       = [];
% c.lfp_channel       = [];
% c.lfps        = int16([]);

% wrap up
fclose (f);
disp (['@cortex object ''' c.name ''' dumped to:']);
disp (['''' name '''']);