function frates = trialfiringrate (c, cluster, binsize, r, group)
%@cortex/trialfiringrate.m
% returns trial-by-trial firing rates from a @cortex object.
%
% FRATES = TRIALFIRINGRATE (COBJ, CLUSTER, BINSIZE, KEY)
%
% where
% FRATES:  M-by-N matrix of spikes/second rates, M trials by N bins;
% COBJ:    the @cortex object;
% CLUSTER: the spike number, as encoded in the CORTEX data file;
% BINSIZE: binsize in ms; a single mean per trial is computed from
%          the whole spikematrix if BINSIZE is omitted;
% KEY:     one key from a @key object
%
% Last modified: 17 Apr 03

% since 17 Apr 00...
% 14 Jul 00: help text fixes
% 11 Nov 02: overloaded function
% 17 Apr 03: call to truncspm

switch nargin
   case 5
      spmat = spikematrix (c, cluster, r, group);
   case 4
      spmat = spikematrix (c, cluster, r);
   case 3
      spmat = spikematrix (c, cluster, binsize);
      binsize = size (spmat, 2);
   otherwise
      error ('wrong number of arguments');
end

if prod (size(binsize))>1
   error ('binsize should be a scalar');
end

% make sure that the length of the array is a multiple of binsize
[spmat, instances, winsize, numofbins] = truncspm (spmat, binsize);

% compute the firing rates
spmat = reshape(spmat, instances, binsize, numofbins);
spptr =  double(sum (spmat, 2)) / binsize * 1000;
frates  = squeeze (spptr);