function ts = trialspikes (c, tr)

% @cortex/trialspikes
%
% returns a matrix containing all the spikes
% recorded in TRIAL of COBJ.
% The 2 columns contain the time stamps,
% and the cluster code, respectively
%
% Syntax:  TS = TRIALSPIKES (COBJ, TRIAL)
%
% Last modified: 20 Sep 99

% 20 sep 99: fix for spikeless trials.

if tr < 1 | tr > c.trials
   error ('trial does not exist');
end

clus = [];
time = [];

for cluster_pos = 1:length(c.cluster_bank)
   first = c.spike_start (tr, cluster_pos);
   last  = c.spike_end   (tr, cluster_pos);
   if first
      time = [time; double(c.spikes(first:last))];
      ctmp = repmat (c.cluster_bank(cluster_pos), last-first+1, 1);
      clus = [clus; ctmp];
   end
end
ttmp = cat (2, time, clus);
if isempty (ttmp)
   ts = [];
else
   ts = sortrows (ttmp, 1);
end