function sp = addsubset (sp, label, units)

%@SPIX/ADDSUBSET   creates a subset of units in a @spix object
%
%   SP = ADDSUBSET(SP,LABEL,UNITS)  stores in SP the subset of units
%   specified in UNITS UNITS can be a unit label, a set of unit labels
%   (in a cell array of strings), one of 'none' 'all' 'first' 'last',
%   or a numeric array specifying the ordinal numbers of the units to
%   will be part of the subset; the string LABEL is the name of the
%   subset.
%
%   SP = ADDSUBSET(SP,LABEL)  the LABEL subset is created with all
%   currently selected units
%
%   Note that if LABEL already exists as a subset name, the new subset
%   will be replace the existing one
%
%Last modified: 21 Aug 03

if nargin == 2
   disp ('all the currently "included" units')
   uni = sp.inclunits;
elseif nargin == 3
   uni = parsegrouping (sp.info, units);
   disp ([num2str(length(uni)) ' units']);
else
   error ('wrong number of arguments');
end

if ~ischar(label), error ('LABEL must be a string'); end
sset = lbl2idx (sp.subsets, label);
if sset
   disp ('replacing an existing subset');
else
   disp ('in a new subset');
   sset = length(sp.subsets) + 1;
   sp.subsets(sset).label = label;
   sp.nsubs = sset;
end

sp.subsets(sset).units = uni;
