function [yestrials, uni, grp] = trialsetnew (sp, varargin)

%@SPIX/TRIALSET   finds trial indices in @spix object
%
%   TSET = TRIALSET(SP) returns a vector containing the trial indices
%   matching the currently included units and keys.
%
%   TSET = TRIALSET(SP,ARGS) returns trials specified by the ARGS
%   conditions. See online help for help on valid ARGS
%
% CHANGE THIS!
%   [TSET,UNI] = TRIALSET(...) instead of returning a single vector,
%   trial idices are placed in the TSET cell array; each cell contains
%   trial indices for one unit; UNI is the list of unit numbers included
%   in the analysis
%
%Modified: 26 Apr 03

% 23 apr 03, by Giuseppe Bertini
%    function created pasting code from findyestrials.m
% 26 Apr 03: groups of keys

nar = length (varargin);
if rem (nar, 2)
   error ('wrong number of arguments');
end

yestrials = [];

for coppia = 1:2:nar
   tipo = minifield (varargin{coppia});
   value = varargin{coppia+1};
   
   switch tipo
      case 'uni'
         if exist('units', 'var'), error ('already defined!'); end
         units = parsesubset (sp, value);
         if isempty (units), error ('no units'); end
      case 'sub'
         if exist('units', 'var'), error ('already defined!'); end
         subset = parsegrouping(sp.info, value);
         if ~scalar (subset), error ('only one subset, please'); end
         units = sp.subsets(subset).units;
      case 'key'
         keys = parsekeys (sp, value);
         if isempty (keys), error ('no keys'); end
      case 'gro'
         groups = parsegrouping (sp.groups, value);
      case 'fac'
         fact = parsegrouping (sp.factors, value);
         if ~scalar (fact), error ('only one factor, please'); end
      case 'lev'
         if ~exist('fact', 'var'), error ('must pass factor before levels'); end
         levels = parsegrouping (sp.factors(fact).levels, value);
      otherwise
         error ('bad parameter')
   end
end   

%%%%%%%%%%%%%%%%
% handle units %
%%%%%%%%%%%%%%%%
if ~exist ('units', 'var'), units=sp.inclunits; end
uid = ismember (double (sp.unit), units);

%%%%%%%%%%%%%%%%%
% handle groups %
%%%%%%%%%%%%%%%%%

if exist('groups', 'var')+exist('fact', 'var')+exist('keys', 'var') > 1
   error ('too many specs');
end

if exist ('groups', 'var')
   for jj=groups
      kk = sp.groups(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
   
elseif exist ('fact', 'var')
   if length(fact) > 1, error ('only one factor, please'); end
   if ~exist ('levels')
      levels = 1:length(sp.factors(fact).levels);
   end
   uni=[]; grp=[];
   for jj = levels
      kk = sp.factors(fact).levels(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
      
else
   if ~exist('keys', 'var'), keys = sp.inkeys; end
   kid = ismember (double(sp.key), keys);
   yestrials = find (uid & kid & sp.yest);
   uni = sp.unit (yestrials);
   grp = sp.key (yestrials);
end

disp ('done trialset')