function [yestrials, uni, grp] = trialsetold (sp, varargin)

%@SPIX/TRIALSET   finds trial indices in @spix object
%
%   TSET = TRIALSET(SP) returns a vector containing the trial indices
%   matching the currently included units and keys.
%
%   TSET = TRIALSET(SP,ARGS) returns trials specified by the ARGS
%   conditions. See online help for help on valid ARGS
%
% CHANGE THIS!
%   [TSET,UNI] = TRIALSET(...) instead of returning a single vector,
%   trial idices are placed in the TSET cell array; each cell contains
%   trial indices for one unit; UNI is the list of unit numbers included
%   in the analysis
%
%Modified: 26 Apr 03

% 23 apr 03, by Giuseppe Bertini
%    function created pasting code from findyestrials.m
% 26 Apr 03: groups of keys

nar = length (varargin);
if rem (nar, 2)
   error ('wrong number of arguments');
end

yestrials = [];

for coppia = 1:2:nar
   tipo = minifield (varargin{coppia});
   value = varargin{coppia+1};
   
   switch tipo
      case 'gro'
         vn = 'groups';
         sn = 'sp.groups';
      case 'uni'
         vn = 'units';
         sn = 'sp.info';
      case 'sub'
         vn = 'subset';
         sn = 'sp.subsets';
      case 'key'
         vn = 'keys';
         sn = 'sp.k';
      case 'fac'
         vn = 'fact';
         sn = 'sp.factors';
      case 'lev'
         if ~exist('fact', 'var')
            error ('must pass factor before levels');
         end
         vn = 'levels';
         sn = 'sp.factors(fact).levels';
      otherwise
         error ('bad parameter')
   end
   
   switch class(value)
      case 'char'
         eval (['tt=lbl2idx(' sn ', value);']);
         if ~tt, error (['label ''' value ''' not found']), end;
         eval ([vn '=tt;']);
      case 'double'
         eval ([vn '=getintrange(length(' sn '), value);']);
      otherwise
         error (['bad value to request ' vn]);
   end
end   

%%%%%%%%%%%%%%%%
% handle units %
%%%%%%%%%%%%%%%%
if exist ('subset', 'var')
   if exist ('units', 'var'), error ('cannot request both units and subsets'), end
   units = sp.subsets(subset).units;
end

if ~exist ('units', 'var'), units=sp.inclunits; end
uid = ismember (double (sp.unit), units);

%%%%%%%%%%%%%%%%%
% handle groups %
%%%%%%%%%%%%%%%%%

if exist('groups', 'var')+exist('fact', 'var')+exist('keys', 'var') > 1
   error ('too many specs');
end

if exist ('groups', 'var')
   for jj=groups
      kk = sp.groups(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
   
elseif exist ('fact', 'var')
   if length(fact) > 1, error ('only one factor, please'); end
   if ~exist ('levels')
      levels = 1:length(sp.factors(fact).levels);
   end
   uni=[]; grp=[];
   for jj = levels
      kk = sp.factors(fact).levels(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
      
else
   if ~exist('keys', 'var'), keys = sp.inkeys; end
   kid = ismember (double(sp.key), keys);
   yestrials = find (uid & kid & sp.yest);
   uni = sp.unit (yestrials);
   grp = sp.key (yestrials);
end

disp ('done trialset')
