function [spmat, uni, grp] = spikematrix (sp, win, binsize, varargin)

%@SPIX/SPIKEMATRIX   matrix of ones (spike occurred) and zeros (no spikes)
%
%    SPIKEMATRIX(SP,WIN,BIN) returns a matrix of spike occurrences from the
%    SP @spix object for all currently selected units and for each of the
%    currently selected keys. If WIN is a scalar, then the spike matrix
%    covers a BIN-ms-long epoch starting at WIN. If WIN is a 2-element
%    vector, then the 2 values define the start and end points of the
%    epoch, and BIN (although still required) is ignored. In the return
%    matrix, each column represents one millisecond and each row represents
%    one analyzed trial.
%
%    SPIKEMATRIX(SP,WIN,BIN,VARARGIN) Additional argument pairs restrict
%    the analysis to subsets of units and/or groups of keys. See on-line
%    help for valid RESTRICTIONs
%
%    [SPMAT,UNITS,GROUP] = SPIKEMATRIX(...)
%
%                    ...to be continued...
%
%Last modified: 12 Sep 03

[yest, uni, grp] = trialset (sp, varargin{:});
% [included_trials, i] = sort (sp.trial(yest));

if ischar(win)
   switch minifield (win)
      case 'var'
         if ~isnumscalar (bin), error ('with variable latency analysis, BINSIZE must be a numeric scalar'); end
         for u = unique (uni)'
            % variable latency computations
            span = sp.latency(u) - sp.offset : sp.latency(u) - sp.offset + binsize - 1;
            idx = yest (uni==u);
            chunk(idx, :) = sp.spix (idx, span);
         end
         spmat = full(chunk(yest,:));
      case 'all'
         spmat = full(sp.spix (yest,:));
      case 'pos'
         spmat = full(sp.spix (yest, sp.offset:end));
      case 'pre'
         spmat = full(sp.spix (yest, 1:sp.offset));
      otherwise
         error ('bad parameter');
   end
elseif isnumeric(win)
   if length(win)==1
      if ischar (binsize)
         if ~strcmp (minifield(binsize), 'all'), error ('bad parameter'); end
         win(2) = size (sp.spix, 2);
      elseif isnumscalar (binsize)
         win(2) = win + binsize -1;
      else
         error ('bad parameter');
      end
   end
   spmat = full(sp.spix (yest, win(1)-sp.offset:win(2)-sp.offset));
else
   error ('bad parameter');
end
