function [yestrials, uni, grp] = trialset (sp, varargin)

%@SPIX/TRIALSET   finds trial indices in @spix object
%
%   TSET = TRIALSET(SP) returns a vector containing the trial indices
%   matching the currently included units and keys.
%
%   TSET = TRIALSET(SP,ARGS) returns trials specified by the ARGS
%   conditions. See online help for help on valid ARGS
%
% CHANGE THIS!
%   [TSET,UNI] = TRIALSET(...) instead of returning a single vector,
%   trial idices are placed in the TSET cell array; each cell contains
%   trial indices for one unit; UNI is the list of unit numbers included
%   in the analysis
%
%Modified: 12 Sep 03

% 23 apr 03, by Giuseppe Bertini
%    function created pasting code from findyestrials.m
% 26 Apr 03: groups of keys
%  9 Aug 03: combos replacing groups; groups are now sets of
%            independently analyzed keys
% 12 Sep 03: eliminating redundant lines

nar = length (varargin);
if rem (nar, 2)
   error ('wrong number of arguments');
end

yestrials = [];

for coppia = 1:2:nar
   tipo = minifield (varargin{coppia});
   value = varargin{coppia+1};
   
   switch tipo
      case 'uni'
         if exist('units', 'var'), error ('already defined!'); end
         units = parsegrouping (sp.info, value);
      case 'sub'
         if exist('units', 'var'), error ('already defined!'); end
         subset = parsegrouping(sp.subsets, value);
         if ~isnumscalar (subset), error ('only one subset, please'); end
         units = sp.subsets(subset).units;
      case 'key'
         keys = parsegrouping (sp.k, value);
      case 'gro'
         group = parsegrouping (sp.groups, value);
         if ~isnumscalar (group), error ('only one group, please'); end
         keys = sp.groups(group).keys;
      case 'com'
         combos = parsegrouping (sp.combos, value);
      case 'fac'
         fact = parsegrouping (sp.factors, value);
         if ~isnumscalar (fact), error ('only one factor, please'); end
      case 'lev'
         if ~exist('fact', 'var'), error ('levels must be preceded by a factor in the argument list'); end
         levels = parsegrouping (sp.factors(fact).levels, value);
      otherwise
         error ('bad parameter')
   end
end   

%%%%%%%%%%%%%%%%
% handle units %
%%%%%%%%%%%%%%%%
if ~exist ('units', 'var'), units=sp.inclunits; end
uid = ismember (double (sp.unit), units);

%%%%%%%%%%%%%%%
% handle keys %
%%%%%%%%%%%%%%%

if exist('combos','var')+exist('fact','var')+exist('keys','var') > 1
   error ('too many DETAIL arguments');
end
uni=[]; grp=[];

if exist ('combos', 'var')
   for jj=combos
      kk = sp.combos(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
   
elseif exist ('fact', 'var')
   if ~exist ('levels', 'var')
      levels = 1:length(sp.factors(fact).levels);
   end
   for jj = levels
      kk = sp.factors(fact).levels(jj).keys;
      kid = ismember (double(sp.key), kk);
      yt = find (uid & kid & sp.yest);
      yestrials = [yestrials; yt];
      uni = [uni; sp.unit(yt)];
      grp = [grp; repmat(jj,size(yt))];
   end
      
else
   if ~exist('keys', 'var'), keys = sp.inkeys; end
   kid = ismember (double(sp.key), keys);
   yestrials = find (uid & kid & sp.yest);
   uni = sp.unit (yestrials);
   grp = sp.key (yestrials);
end

if sp.verbose, disp ([num2str(length(yestrials)) ' trials found']); end