function cortview (c)

% Last modified: 29 Jul 99

cvh = findobj ('tag', 'CortViewFigure');
if isa (c, 'cortex')
   
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   % is a cortview figure already present? %
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
   if isempty (cvh)
      
      % No, create one.
      % First some data to create objects on window
      y1 = 350:-25:0;
      ly = length (y1);
      y2 = repmat (20, 1, ly);
      x1 = repmat (10, 1, ly);
      x2 = repmat (70, 1, ly);
      x3 = repmat (85, 1, ly);
      x4 = repmat (40, 1, ly);
      d = [x1; y1; x2; y2; x3; x4]';
      st = {'Trial' 'Condition' 'Block' 'Repetition' 'EOG (ms)' 'Data (KHz)' 'Type' 'Expected' 'Response'};
      
      cvh = figure ( ...
         'name', c.name, ...
         'tag', 'CortViewFigure', ...
         'userdata', c, ...
         'units', 'pixels', ...
         'position', [100 100 580 400], ...
         'menubar', 'none', ...
         'numbertitle', 'off', ...
         'defaultuicontrolstyle', 'text', ...
         'defaultuicontrolfontsize', 9, ...
         'defaultuicontrolhorizontalalignment', 'left');
      for i=1:9
         u(i)=uicontrol ('string', st{i}, 'position', d(i,1:4));
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % create the header info textboxes %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      set (cvh, ...
         'defaultuicontrolbackgroundcolor', 'w', ...
         'defaultuicontrolhorizontalalignment', 'right', ...
         'defaultuicontrolfontname', 'courier');
      
      st = {'cvTrial' 'cvCond' 'cvBlock' 'cvRept' 'cvEOG' 'cvKHz' 'cvType' 'cvExp' 'cvResp'};
      for i=1:9
         ctr (i) = uicontrol ('tag', st{i}, 'position', d(i, [5 2 6 4]));
      end
      
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % create code & spike listboxes %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      
      evt = uicontrol ( ...
         'tag', 'cvEventList', ...
         'style', 'list', ...
         'pos', [140 50 240 320]);
      spk = uicontrol ( ...
         'tag', 'cvSpikeList', ...
         'style', 'list', ...
         'pos', [390 50 150 320]);
        
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      % create the browsing pushbuttons %
      %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
      set (cvh, 'defaultuicontrolstyle', 'pushbutton');
      puf = uicontrol ( ...
         'tag', 'cvFirsTrial', ...
         'String', '<<', ...
         'Call', 'cortview ''firstrial''', ...
         'pos', [10 10 20 20]);
      pup = uicontrol ( ...
         'tag', 'cvPrevTrial', ...
         'String', '<', ...
         'Call', 'cortview ''prevtrial''', ...
         'pos', [30 10 20 20]);
      pun = uicontrol ( ...
         'tag', 'cvNexTrial', ...
         'String', '>', ...
         'Call', 'cortview ''nextrial''', ...
         'pos', [100 10 20 20]);
      pul = uicontrol ( ...
         'tag', 'cvLasTrial', ...
         'String', '>>', ...
         'Call', 'cortview ''lastrial''', ...
         'pos', [120 10 20 20]);
      
      % and the GoTrial editbox
      
      tri = uicontrol ( ...
         'tag', 'cvGoTrial', ...
         'style', 'edit', ...
         'Call', 'cortview gotrial', ...
         'pos', [50 10 50 20]);
      
   else
      % a CortViewFigure already exists.
      % assing the (supposedly) new c object to it
      
      set (cvh, ...
         'userdata', c, ...
         'name', c.name);
      
   end
   
   refresh_dialog (1);
   return;
   
elseif ~isa (c, 'char')
   error ('wrong argument type');
end

% argument c is a string, i.e., an action
% on an existing view

cobj = get (cvh, 'userdata');
h = findobj ('tag', 'cvGoTrial');
tr = eval (get (h, 'string'));

switch c
case 'firstrial'
   refresh_dialog (1);
case 'prevtrial'
   if tr > 1
      refresh_dialog (tr-1);
   end
case 'nextrial'
   if tr < cobj.trials
      refresh_dialog (tr+1);
   end
case 'lastrial'
   refresh_dialog (cobj.trials);
case 'gotrial'
   if tr < 1
      refresh_dialog (1);
   elseif tr > cobj.trials
      refresh_dialog (cobj.trials);
   else
      refresh_dialog (tr);
   end
otherwise
   error ('what the heck?')
end
return

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function refresh_dialog (tr)

h = findobj ('tag', 'CortViewFigure');
c = get (h, 'userdata');

h = findobj ('tag', 'cvGoTrial');
set (h, 'string', tr);

h = findobj ('tag', 'cvTrial');
set (h, 'string', c.rel(tr));

h = findobj ('tag', 'cvCond');
set (h, 'string', c.con(tr));

h = findobj ('tag', 'cvBlock');
set (h, 'string', c.blo(tr));

h = findobj ('tag', 'cvRept');
set (h, 'string', c.rep(tr));

h = findobj ('tag', 'cvResp');
set (h, 'string', c.res(tr));

h = findobj ('tag', 'cvEOG');
set (h, 'string', c.eog(tr));

h = findobj ('tag', 'cvKHz');
set (h, 'string', c.KHz(tr));

h = findobj ('tag', 'cvExp');
set (h, 'string', c.exp(tr));

h = findobj ('tag', 'cvType');
set (h, 'string', c.typ(tr));

h = findobj ('tag', 'cvEventList');
idx = find (c.codes(tr,:));
nix = length (idx);
iii = num2str ((1:nix)');
tmp = c.times (tr,idx)';
ttt = num2str (tmp);
tmp = [0; diff(tmp)];
ddd = num2str (tmp);
ccc = num2str (c.codes (tr, idx)');
spa = repmat (' ', nix, 2);
sss = cat (2, iii, spa, ttt, spa, ddd, spa, ccc);
set (h, 'string', sss);

h = findobj ('tag', 'cvSpikeList');
ts = trialspikes (c, tr);
set (h, 'string', num2str(ts));
