function [f, a, l] = raster (c, cluster, r, group);

% raster.m
%
% draws a raster plot on the current axis
% (if not available, a new figure is created)
%
% Syntax 1: [FH, AX, LN] = RASTER (COBJ, CLUSTER, ROBJ, [GROUP])
% Syntax 2: [FH, AX, LN] = RASTER (SPMAT, [XLIM])
%
% Where:
% COBJ:    the @cortex object;
% SPMAT:   a spike matrix, such as that returned by @cortex\spikematrix.m;
% CLUSTER: the spike number, as encoded in the CORTEX data file;
% ROBJ:    one rule from a @rules object,
%          or the entire object, if GROUP is specified;
% GROUP:   the group to be analyzed (optional);
% XLIM:    times in ms, relative to the cue event, corresponding
%          to the first and the last columns of the SPMAT (optional).
%
% Last modified: 13 OCt 00

% 14 Jul 00: numerous changes, including group handling,
%            SPMAT handling, and removal of figure generation.
% 13 Oct 00: bug: xs=r(2).finish;  -->  xf=r(2).finish;


switch nargin
case 1
   spmat = c;
   xs = 1;
   xf = size(spmat,2);
case 2
   spmat = c;
   xs = cluster(1);
   xf = cluster(2);
case 3
   if sum(r.size)>1
      error ('multi-rule object passed using single-rule syntax');
   end
   spmat = spikematrix (c, cluster, r);
   xs = r.start;
   xf = r.finish;
case 4
   spmat = spikematrix (c, cluster, r, group);
   xs = r(1).start;
   xf = r(2).finish;
otherwise
   error ('wrong number of arguments');
end

[ro, co] = size (spmat);
[ly, lx] = find (spmat);
ly = [ly'+.15; ly'+.85];
lx = [lx' + xs; lx' + xs];

l = line (lx, ly);
axis ij;
set (gca, 'ylim', [1 ro+1], 'xlim', [xs xf], 'tickdir', 'out');
set (l, 'color', 'black');