function frates = trialfiringrate (spmat, binsize)

%TRIALFIRINGRATE   Trial-by-trial firing rates.
% 
% FRATES = TRIALFIRINGRATE (SPMAT, BINSIZE)
% FRATES = TRIALFIRINGRATE (COBJ, CLUSTER, BINSIZE, KEY)
% FRATES = TRIALFIRINGRATE (SPIX
%
% where
% SPMAT:   a spike matrix returned by @cortex\spikematrix.m;
% BINSIZE: binsize in ms; a single mean per trial is computed from
%          the whole spikematrix if BINSIZE is omitted;
% FRATES:  M-by-N matrix of spikes/second rates, M trials by N bins;
% COBJ:    a @cortex object;
% CLUSTER: the spike number, as encoded in the CORTEX data file;
% BINSIZE: binsize in ms; a single mean per trial is computed from
%          the whole spikematrix if BINSIZE is omitted;
% KEY:     one key from a @key object
%
% Last modified: 17 Apr 03

% 17 Apr 00: last unnoted changes
% 14 Jul 00: help text fixes
% 11 Nov 02: overloaded function
% 16 Apr 03: help text; nargin stuff rewritten
% 17 Apr 03: call to truncspm

if ndims (spmat) ~= 2
   error ('the first argument should be a spike matrix');
end
if nargin==1
   binsize = size (spmat, 2);
elseif prod (size(binsize))>1
   error ('binsize should be a scalar');
end
if nargin>2
   error ('wrong number of arguments');
end

% make sure that the length of the array is a multiple of binsize
[spmat, instances, winsize, numofbins] = truncspm (spmat, binsize);

% compute the firing rates
spmat = reshape(spmat, instances, binsize, numofbins);
spptr =  double(sum (spmat, 2)) / binsize * 1000;
frates  = squeeze (spptr);