function yestrials = trialset (c, r, g)

% trialset.m
%
% YES = TRIALSET (COBJ, KEY)
% YES is a vector of trial numbers from the @cortex oject COBJ that 
% match the conditions set by KEY, i.e., one key from a @key object
%
% Last modified: 10 Oct 02

% 11 May 00: group support added
% 14 Jul 00: fixed a bug that produced an error if the r.trials range
%            exceeded the number of existing trials
% 10 Oct 02: @key support added.

y = [];
if nargin < 2
   error ('too few arguments')
else
   if ~isa (c, 'cortex')
      %      error ('first argument must be @cortex object');
   end
   s = r.size;
end
switch class (r)
   case 'rules'
      if prod(s) == 1
         y = gettrialset (c, r);
      else
         if nargin < 3
            error ('multi-rule object passed using single-rule syntax');
         end
         if g < 1 | g > length (s)
            error ('requested group does not exist');
         end
         for rule = 1:s(g)
            y = [y, gettrialset(c,r(g,rule))];
         end
      end
   case 'key'
      if nargin > 2
         warning ('only two arguments needed; extra args ignored')
      end
      nk = r.size;
      
      if length(nk) > 1
         error ('trialset cannot process more than one key');
      end
      for sk = 1:nk
         y = [y, gettrialset(c,r(1,sk))];
      end
   otherwise
      error ('second argument must be a key (or @rule object)');
end
yestrials = sort (y);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function yest = gettrialset (c, r)

if r.trials ~= -1
   yes = zeros (length (c.conds), 1);
   its = intersect (1:c.tri, r.trials);
   yes (its) = 1;
else
   yes = ones (length(c.conds), 1);
end

if r.conds ~= -1
   mb = ismember (c.conds, r.conds);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if r.blocks ~= -1
   mb = ismember (c.blocks, r.blocks);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if r.resps ~= -1
   mb = ismember (c.resps, r.resps);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if r.type ~= -1
   mb = ismember (c.type, r.type);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end

if r.expect ~= -1
   mb = ismember (c.expect, r.expect);
   if ~isempty (mb)
      yes = and (yes, mb);
   end
end
try
   if r.rept ~= -1
      mb = ismember (c.expect, r.rept);
      if ~isempty (mb)
         yes = and (yes, mb);
      end
   end
catch
end

yest = (find(yes))';