function ScanCortexFile (source_filename)

% ScanCortexFile.m
%
% this function does absolutely nothing.
% Well, actually, it goes through a CORTEX data file
% and if the file is corrupted chances are--
% it will report an error.
%
% Its real purpose is to provide a quick reference to
% the CORTEX data file structure for the programmer
%
% Usage: SCANCORTEXFILE (PATH/FILENAME)
%
% Last modified: 28 Jan 99

UINT8  = 1;
UINT16 = 2;
UINT32 = 4;

[f, msg] = fopen (source_filename, 'r');
if f == -1
    error (msg);
end

trial = 0;

while 1 %not_eof
    
    header_length  = fread (f, 1, 'uint16'); % length of header in bytes; should always be 26
    
    % check for eof and for file integrity (header size should be 26)
    if isempty (header_length)
        disp ('done.');
        break
    elseif header_length ~= 26
        error ('possible file corruption: the header should be 26 bytes long');
    else
        trial = trial + 1;
    end
    
    cond_no        = fread (f, 1, 'uint16'); % base 0 !!!
    repeat_no      = fread (f, 1, 'uint16'); % base 0 !!! 
    block_no       = fread (f, 1, 'uint16'); % base 0 !!!
    trial_no       = fread (f, 1, 'uint16'); % base 1 !!!
    
    timebuf_size   = fread (f, 1, 'uint16'); % length in bytes of the time stamp buffer
    codebuf_size   = fread (f, 1, 'uint16'); % length in bytes of the encodes buffer
    eogbuf_size    = fread (f, 1, 'uint16'); % length in bytes of the eog buffer
    eppbuf_size    = fread (f, 1, 'uint16'); % length in bytes of the epp buffer
    
    eog_rate       = fread (f, 1, 'uint8' ); % ms between eog samples. set in General Parameters
    KHz_resolution = fread (f, 1, 'uint8' ); % data collection sampling rate. idem
    
    trial_type     = fread (f, 1, 'uint16'); % an attribute of the condition
    exp_response   = fread (f, 1, 'uint16'); % the argument passed to the response_xxx() function
    response       = fread (f, 1, 'uint16'); % the value returned by the response_xxx() function
    
    % a check for file integrity
    if timebuf_size/UINT32 ~= codebuf_size/UINT16
        warning ('possible file corruption: timebuf vs. codebuf mismatch');
    end
    
    % buffers
    times          = fread (f, timebuf_size/UINT32, 'uint32');
    codes          = fread (f, codebuf_size/UINT16, 'uint16');
    eog            = fread (f, eogbuf_size /UINT16, 'uint16');
    epp            = fread (f, eppbuf_size /UINT16, 'uint16');
end